@@ -183,14 +183,14 @@ class Base_Page(Borg, unittest.TestCase):
 
         return self.calling_module
 
-    def set_directory_structure(self, invocation_dir):
+    def set_directory_structure(self):
         "Setup the required directory structure if it is not already present"
         try:
             self.screenshots_parent_dir = os.path.abspath(
                 os.path.join(os.path.dirname(__file__), '../../../..', 'screenshots', self.product))  # Real screencap folder dir
             if not os.path.exists(self.screenshots_parent_dir):
                 os.makedirs(self.screenshots_parent_dir)
-            self.logs_parent_dir = os.path.abspath(os.path.join(invocation_dir.strpath, '../../../..', 'log',
+            self.logs_parent_dir = os.path.abspath(os.path.join(os.path.dirname(__file__), '../../../..', 'log',
                                                                 self.product))          # Real log file dir base on Base_Logging.py constructor
             if not os.path.exists(self.logs_parent_dir):
                 os.makedirs(self.logs_parent_dir)
